@@ -5,22 +5,24 @@ from datetime import datetime, timedelta
 
 from tank_forecaster.decomp import generic_daily_decomp
 
-
 def format_tank(dict_input, freq: str = '30min'):
-    dict_input = sorted(dict_input, key=lambda x: x['read_time'])
-    df = pd.DataFrame(dict_input)
-    df.read_time = pd.to_datetime(df.read_time)
-    df['y'] = df.volume.diff() * -1
-    df = df[['read_time', 'y']].rename(columns={'read_time': 'ds'})
-    df.y = df.y.clip(lower=0, upper=df.y.quantile(0.9999))
-    df = df.set_index('ds').groupby(pd.Grouper(freq=freq)).sum()
-    df.reset_index(level=0, inplace=True)
-    return df.iloc[1:-1]
+    if dict_input == []:
+        return None
+    else:
+        dict_input = sorted(dict_input, key=lambda x: x['read_time'])
+        df = pd.DataFrame(dict_input)
+        df.read_time = pd.to_datetime(df.read_time)
+        df['y'] = df.volume.diff() * -1
+        df = df[['read_time', 'y']].rename(columns={'read_time': 'ds'})
+        df.y = df.y.clip(lower=0, upper=df.y.quantile(0.9999))
+        df = df.set_index('ds').groupby(pd.Grouper(freq=freq)).sum()
+        df.reset_index(level=0, inplace=True)
+        return df.iloc[1:-1]
 
 
 def format_sales(dict_input):
-    if not dict_input:
-        return 'no data'
+    if dict_input == []:
+        return None
     else:
         dict_input = sorted(dict_input, key=lambda x: x['date'])
         dat = pd.DataFrame(dict_input)
